=====
Space
=====

This module contains classes for defining the function space spanned
by the :class:`ClusterSubspace`.

.. toctree::
   :maxdepth: 2

   space.basis
   space.cluster
   space.domain
   space.orbit
   space.constants
